# AZDSDR - Data Scientist's Data Reader

This package includes data reader for DS to access data in a easy way. 

Covered data platforms
    * Dremio
    * Kusto
  
## Prepare to use Dremio

[TBD]

## Prepare to use Kusto

[TBD]